if (typeof jQuery === 'undefined') {
    throw new Error('LN requires jQuery')
}
"use strict";
var LN = {};

LN.android = (function() {
    var u = navigator.userAgent;
    return u.indexOf('Android') > -1 || u.indexOf('Adr') > -1;
})();

LN.ios = (function() {
    var u = navigator.userAgent;
    return !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
})();

window.onload = function() {
};

LN.callbackQueue = [];
LN.runCallbackQueue = function() {
    if (LN.callbackQueue.length === 0) {
        return;
    }

    setTimeout(function() {
        window.location.href = "ln-callback://";
    }, 0);
};

LN.getCommandQueue = function() {
    var commands = JSON.stringify(LN.callbackQueue);
    LN.callbackQueue = [];
    return commands;
};

LN.callback = function(method) {
    if (LN.android) {
        setTimeout(function() {
            return window.location = method;
        }, 100);
        return;
    }
    LN.callbackQueue.push(method);
    LN.runCallbackQueue();
};

LN.downloadImage = function(url) {
    LN.callback('lntsfc://image?url=' + url);
}

LN.downloadImages = function(urls) {
    var _urls = $.unique(urls);
    LN.callback('lntsfc://images/' + JSON.stringify(_urls));
}

LN.replaceImage = function(url, data) {
    $("img.lazy[data-src='" + url +"']")
        .attr('src', data)
        .removeClass('lazy')
        .fadeIn();
};


LN.requestQueue = [];

LN.data = function(id, data) {
    $.each(LN.requestQueue, function(index, val) {
        if (val.id == id) {
            LN.requestQueue.slice(index, 1);
            if (typeof val.callback == 'function') {
                return val.callback(data);
            }
        }
    });
}

LN.request = function(method, url, params, callback) {
    var id = 'ln' + (new Date()).getTime() + "" + parseInt(Math.random() * 1000);
    LN.requestQueue.push({
        id: id,
        callback: callback
    });
    var body = {
       'id': id,
       'url': url,
       'method': method,
       'params': params,
   };
    if (LN.ios) {
        if (!window.webkit || !window.webkit.messageHandlers || !window.webkit.messageHandlers.request) {
            alert("no js bridge");
            return;
        }
        var bridge = window.webkit.messageHandlers.request;
        bridge.postMessage(body);
    } else if(LN.android) {
        if(!window.jsBridge) {
            return alert("no request bridge");
        }
        window.jsBridge.request(JSON.stringify(body));
    } else {
        var deviceId = "b45f0716-6ab6-4ad0-9c8d-d67b8fd9b9ba";
        var nonce = '1234567890';
        var timestamp = Date.parse(new Date()) / 1000;
        var data = {};
        $(params).each(function(index, el) {
            data[el.name] = el.value;
        });
        $.ajax({
            'url': url,
            'method': method,
            'data': data,
            'dataType': 'json',
            'crossDomain': true,
            'headers': {
                'App': 'test',
                'Timestamp': timestamp,
                'Device': deviceId,
                'Nonce': nonce,
                'Auth': sha256_digest('8B8D4sW8MkQEcc4E2aig5ytlWjhXJrFb' + timestamp + deviceId + url + nonce),
            },
            'success': function(result) {
                callback(result);
            }
        });
    }
}

LN.get = function(url, params, callback) {
    LN.request('get', url, params, callback);
}
LN.post = function(url, params, callback) {
    LN.request('post', url, params, callback);
};

LN.login = function(user) {
    if (LN.ios) {
        if (!window.webkit || !window.webkit.messageHandlers || !window.webkit.messageHandlers.authent) {
            alert("no js bridge");
            return;
        }
        var bridge = window.webkit.messageHandlers.authent;
        bridge.postMessage(user);
    } else if(LN.android) {
        if(!window.jsBridge || !window.jsBridge.authent) {
            return alert("no request bridge");
        }
        window.jsBridge.authent(JSON.stringify(user));
    } else {
        console.log(user);
        alert("登录成功，用户信息请在Console中查看");
    }
}

LN.register = function(user) {
    if (LN.ios) {
        if (!window.webkit || !window.webkit.messageHandlers || !window.webkit.messageHandlers.registerResult) {
            alert("no js bridge");
            return;
        }
        var bridge = window.webkit.messageHandlers.registerResult;
        bridge.postMessage(user);
    } else if(LN.android) {
        if(!window.jsBridge || !window.jsBridge.registerResult) {
            return alert("no request bridge");
        }
        window.jsBridge.registerResult(JSON.stringify(user));
    } else {
        console.log(user);
        alert("注册成功，用户信息请在Console中查看");
    }
}

LN.imageQueue = [];
LN.uploadImage = function(callback, usage) {
    if (!usage) {
        usage = 'user';
    }
    var id = 'li' + (new Date()).getTime() + "" + parseInt(Math.random() * 1000);
    LN.imageQueue.push({
        id: id,
        callback: callback
    });
    LN.callback('lntsfc://image/upload?width=300&&height=300&callback=' + id + '&usage=' + usage);
}

LN.image = function(url, base64) {
    $("img.lazy[data-src=" + url + "]").attr('src', 'data:image/png;base64,' + base64);
}

LN.loadImages = function() {
    var images = [];
    $('img.lazy').each(function(index, el) {
        var $this = $(this);
        images.push($this.data('src'));
    });
    LN.downloadImages(images);
}

LN.init = function() {
    FastClick.attach(document.body);
}